<?php
/**
 * @file
 * Organic groups Titles migration class.
 */


/**
 * Migrate Organic groups titles available for use as user titles to Drupal 7.
 */
class OgTitlesMigrate extends DynamicMigration {

  protected $systemOfRecord = Migration::DESTINATION;

  public function __construct(array $arguments) {
    $this->arguments = $arguments;
    parent::__construct();

    $bundle = isset($arguments['bundle']) ? $arguments['bundle'] : FALSE;
    $this->description = t('Upgrade group membership titles available to use as group member titles into field data.');
    $this->dependencies = array('OgTitlesAddFields');

    // Set the source key to node id.
    $source_key = MigrateDestinationNode::getKeySchema();
    $source_key['nid']['alias'] = 'n';

    // Query to fetch group titles. Migrate is retarded and does not handle
    // multivalue source mapping in a SANE way. Distinct, really..? Come on!
    $query = db_select('og_titles', 'ogt');
    $query->innerJoin('node', 'n', 'ogt.nid = n.nid');
    $query
      ->fields('ogt', array('nid'))
      ->condition('n.type', $bundle)
      ->orderBy('ogt.nid')
      ->orderBy('ogt.weight')
      ->distinct();
    $this->query = $query;

    $this->map = new MigrateSQLMap($this->machineName, $source_key, MigrateDestinationNode::getKeySchema());
    $this->source = new MigrateSourceSQL($this->query);
    $this->destination = new MigrateDestinationNode($bundle);

    $this->addFieldMapping('nid', 'nid');
    $this->addFieldMapping('group_titles', 'title');
  }

  /**
   * Query og titles AGAIN because Migrate module does not have a sane method
   * of handling multivalue fields. MigrateWTF.
   */
  public function prepareRow($current_row) {
    $result = db_select('og_titles')
      ->condition('nid', $current_row->nid)
      ->fields('og_titles', array('title'))
      ->orderBy('weight')
      ->execute();

    foreach ($result as $record) {
      $current_row->title[] = $record->title;
    }

    return TRUE;
  }

  /** 
   * Construct the machine name from the bundle.
   */
  protected function generateMachineName($class_name = NULL) {
    if (!isset($this->arguments['bundle'])) {
      return drupal_strtolower('OgTitlesMigrateUnkown');
    }

    return drupal_strtolower('OgTitlesMigrate' . ucfirst($this->arguments['bundle']));
  }
}
