<?php
/**
 * @file
 * Organic groups Titles field migration class.
 */

/**
 * Create necessary fields for group entities and group membership entities.
 */
class OgTitlesAddFields extends MigrationBase {

  public function __construct() {
    parent::__construct();
    $this->description = t('Add required fields to group entities and group membership type.');
    $this->enabled = !$this->isComplete();

    // Dependency on Og Migrate.
    // $this->dependencies = array('OgMigrateGroup');
  }

  public function isComplete() {
    return variable_get('og_titles_7000_add_field', TRUE);
  }

  /**
   * Create text field with group membership widget based on configuration in
   * Drupal 6, and then create group member title fields on the group
   * membership bundle.
   */
  public function import() {

    // Find all group node entities. Non-node groups were not supported in
    // Organic groups versions prior to Drupal 7. Do not trust that the user
    // may not have created additional groups.
    $query = db_select('og_titles', 'ogt');
    $query->join('node', 'n', 'ogt.nid = n.nid');
    $query
      ->fields('n', array('type'));
    $query->distinct();

    $types = $query->execute()->fetchAllKeyed(0, 0);
    foreach ($types as $type) {
      og_create_field('group_titles', 'node', $type);  
    }

    // Create group membership title field on group membership bundles based on
    // Drupal 6 settings.
    $d6_selection_type = variable_get('og_titles_selection', 'og_titles_text_input');
    $map = array(
      'og_titles_text_input' => 'text_textfield',
      'og_titles_select_input' => 'og_titles_select',
    );
    $widget = isset($map[$d6_selection_type]) ? $map[$d6_selection_type] : 'og_titles_text_input';

    $types = $this->getMembershipTypes();

    foreach ($types as $name => $type) {
      og_create_field('group_member_title', 'og_membership', $name);

      // Set the widget appropriately.
      $instance = field_read_instance('og_membership', 'group_member_title', $name);
      $instance['widget']['type'] = $widget;
      field_update_instance($instance);
    }

    variable_del('og_titles_7000_add_field');
    variable_del('og_titles_selection');

    return MigrationBase::RESULT_COMPLETED;
  }

  /**
   * Return membership types as there is no Organic groups API function to do
   * so.
   *
   * @return array
   *   An array of OgMembershipType keyed by the OgMembership bundle entity key.
   */
  protected function getMembershipTypes() {
    return db_select('og_membership_type', 'g') 
      ->fields('g')
      ->execute()
      ->fetchAllAssoc('name');
  }
}
