<?php
/**
 * @file
 * Organic groups users titles migration class.
 */


/**
 * Migrates organic groups user titles to og_member_titles field type.
 */
class OgUserTitlesMigrate extends DynamicMigration {

  public function __construct() {
    parent::__construct();

    $this->description = t('Migrate group member titles to field data.');

    // Dependencies
    foreach (node_type_get_names() as $bundle => $value) {
      // Dependent on a dynamic migration.
      $machine_name = 'OgTitlesMigrate' . ucfirst($bundle);
      if (MigrationBase::getInstance($machine_name, 'OgTitlesMigrate', array('bundle' => $bundle))) {
        $this->dependencies[] = $machine_name;
      }
    }

    // Build a query against og_uid_titles and og_membership.
    $query = db_select('og_uid_titles', 'ogut');
    $query->leftJoin('og_membership', 'ogm', 'ogut.nid = ogm.gid AND ogut.uid = ogm.etid');
    $query
      ->fields('ogut', array('nid', 'uid', 'title', 'weight'))
      ->fields('ogm', array('id'))
      ->condition('ogm.entity_type', 'user')
      ->condition('ogm.group_type', 'node')
      ->orderBy('ogut.nid');
    $this->query = $query;

    // Shamelessly stolen from OgUserMigrate.
    $source_key = array(
      'nid' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'node ID of group.',
      ),
      'uid' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'User ID of member.',
      ),
    );

    $this->map = new MigrateSQLMap($this->machineName, $source_key, MigrateDestinationOGMemberTitle::getKeySchema());
    $this->source = new MigrateSourceSQL($this->query);
    $this->destination = new MigrateDestinationOGMemberTitle();

    // Add Group Membership mapping.
    $this->addFieldMapping('group_type', NULL)->defaultValue('node');
    $this->addFieldMapping('gid', 'nid');
    $this->addFieldMapping('entity_type', NULL)->defaultValue('user');
    $this->addFieldMapping('etid', 'uid');
    $this->addFieldMapping('id', 'id');

    // Add Title field mapping
    $this->addFieldMapping('group_member_title', 'title');
    $this->addFieldMapping('group_member_title:weight', 'weight')->defaultValue(0);

    return TRUE;
  }

}

