<?php
/**
 * @file
 * Import Organic group member tiles.
 */

/**
 * Destination class implementing migration into an OG Membership field.
 */
class MigrateDestinationOGMemberTitle extends MigrateDestination {

  public function __toString() {
    return t('og-member-title');
  }

  static public function getKeySchema() {
    return array(
      'id' => array(
        'description' => "The group membership's unique ID.",
        'type' => 'int',
        'not null' => TRUE,
      ),
    );
  }

  /**
   * Remove membership title by membership id.
   *
   * @param $id
   *  IDs to be deleted.
   */
  public function rollback(array $id) {
    $membership = og_membership_load($id);
    $membership->group_member_title = NULL;
    og_membership_save($membership);
  }

  /**
   * Remove many member titles.
   *
   * @param $ids
   *   Array of membership ids to be deleted.
   */
  public function bulkRollback(array $ids) {
    $memberships = og_membership_load_multiple($ids);
    foreach ($memberships as $id => $membership) {
      $membership->group_member_title = NULL;
      og_membership_save($membership);
    }
  }

  /**
   * Import a single member title.
   *
   * @param $entity
   *  The object to build filled with any fields mapped in the Migration.
   * @param $row
   *  Raw source data object - passed through to prepare/complete handlers.
   * @return array
   *  Array of key fields of the object that was saved if
   *  successful. FALSE on failure.
   */
  public function import(stdClass $entity, stdClass $row) {
    if (empty($entity->group_type)) {
      throw new MigrateException('Missing group type.');
    }
    if (empty($entity->gid)) {
      throw new MigrateException('Missing group ID.');
    }
    if (empty($entity->entity_type)) {
      throw new MigrateException('Missing entity type.');
    }
    if (empty($entity->etid)) {
      throw new MigrateException('Missing entity ID.');
    }

    try {
      $id = $entity->id;

      if (!$id) {
        // Throw exception or just not do anything?
        throw new MigrateException(t('Could not find a membership for user %uid in group %gid.', array('%uid' => $entity->etid, '%gid' => $entity->gid)));
      }

      $membership = og_membership_load($id);

      error_log(print_r($entity, TRUE));

      $membership->group_member_title['und'] = array(array(
        'value' => $entity->group_member_title[0],
        'weight' => $entity->group_member_title['arguments']['weight'],
      ));

      og_membership_save($membership);
    }
    catch (Exception $e) {
      throw new MigrateException($e->getMessage());
    }

    return array($membership->id);
  }

  public function fields() {
    return array(
      'id' => 'Group membership id',
      'group_type' => 'Group type',
      'gid' => 'Group id',
      'entity_type' => 'Group membership entity type',
      'etid' => 'Entity id',
      'group_member_title' => 'Member title',
      'group_member_title:weight' => 'Member title weight',
    );
  }
}
